@@ -1809,12 +1809,10 @@ void displayModesMessage(struct modesMessage *mm) {
     if (mm->score)
         printf("Score: %d\n", mm->score);
 
-    if (mm->timestampMsg) {
-        if (mm->timestampMsg == MAGIC_MLAT_TIMESTAMP)
-            printf("This is a synthetic MLAT message.\n");
-        else
-            printf("Time: %.2fus\n", mm->timestampMsg / 12.0);
-    }
+    if (mm->timestampMsg == MAGIC_MLAT_TIMESTAMP)
+        printf("This is a synthetic MLAT message.\n");
+    else
+        printf("Time: %.2fus\n", mm->timestampMsg / 12.0);
 
     switch (mm->msgtype) {
         case 0:
