@@ -57,6 +57,8 @@
 
 #include <stdarg.h>
 
+struct _Modes Modes;
+
 //
 // ============================= Program options help ==========================
 //
@@ -166,7 +168,7 @@ static void modesInitConfig(void) {
     Modes.net_connector_delay = 30 * 1000;
     Modes.interactive_display_ttl = MODES_INTERACTIVE_DISPLAY_TTL;
     Modes.json_interval = 1000;
-    Modes.json_location_accuracy = 1;
+    Modes.json_location_accuracy = 2;
     Modes.maxRange = 1852 * 300; // 300NM default max range
     Modes.mode_ac_auto = 1;
     Modes.nfix_crc = 1;
@@ -768,6 +770,11 @@ int main(int argc, char **argv) {
 
     // Parse the command line options
     if (argp_parse(&argp, argc, argv, 0, 0, 0)) {
+        fprintf(stderr, "Command line used:\n");
+        for (int i = 0; i < argc; i++) {
+            fprintf(stderr, "%s ", argv[i]);
+        }
+        fprintf(stderr, "\n");
         cleanup_and_exit(1);
     }
 
@@ -812,23 +819,18 @@ int main(int argc, char **argv) {
      * This rules also in case a local Mode-S Beast is connected via USB.
      */
     if (Modes.sdr_type == SDR_NONE || Modes.sdr_type == SDR_MODESBEAST || Modes.sdr_type == SDR_GNS) {
-        int64_t background_cpu_millis = 0;
-        int64_t prev_cpu_millis = 0;
         struct timespec slp = {0, 20 * 1000 * 1000};
         while (!Modes.exit) {
             int64_t sleep_millis = 100;
             struct timespec start_time;
 
-            prev_cpu_millis = background_cpu_millis;
-
             start_cpu_timing(&start_time);
             backgroundTasks();
-            end_cpu_timing(&start_time, &Modes.stats_current.background_cpu);
+            int64_t elapsed = end_cpu_timing(&start_time, &Modes.stats_current.background_cpu);
 
-            background_cpu_millis = (int64_t) Modes.stats_current.background_cpu.tv_sec * 1000UL +
-                Modes.stats_current.background_cpu.tv_nsec / 1000000UL;
-            sleep_millis = sleep_millis - (background_cpu_millis - prev_cpu_millis);
-            sleep_millis = (sleep_millis <= 20) ? 20 : sleep_millis;
+            sleep_millis = 100 - elapsed;
+            sleep_millis = (sleep_millis < 10) ? 10 : sleep_millis;
+            sleep_millis = (sleep_millis > 100) ? 100 : sleep_millis;
 
             //fprintf(stderr, "%ld\n", sleep_millis);
 
